@@ -1,4 +1,3 @@
-#! /usr/bin/env python
 # -*- coding: UTF-8 -*-
 
 """
@@ -19,19 +18,5 @@ You should have received a copy of the GNU General Public License
 along with this program.  If not, see <http://www.gnu.org/licenses/>.
 """
 
-__all__ = ['core', 'gui', 'datasets', 'parameters']
-__version__ = '0.4.1'
-
-import gettext
-import os
-import sys
-
-def gettext_install():
-    """Installs string translations; uses local data if available."""
-    basepath = os.path.dirname(os.path.abspath(sys.path[0]))
-    if os.path.exists(os.path.join(basepath, 'po/mo')):
-        gettext.install('pondus', os.path.join(basepath, 'po/mo'))
-    else:
-        gettext.install('pondus', os.path.join(basepath, 'share/locale'))
-
-gettext_install()
+__all__ = ['core', 'gui', 'parameters', 'user_data']
+__version__ = '0.5.3'
