@@ -1,4 +1,3 @@
-#! /usr/bin/env python
 # -*- coding: UTF-8 -*-
 
 """
@@ -21,5 +20,5 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 __all__ = ['dialog_add', 'dialog_csv_export', 'dialog_csv_import',
            'dialog_message', 'dialog_plot', 'dialog_preferences',
-           'dialog_remove', 'dialog_save_file', 'dialog_select_file',
-           'guiutil', 'window_main']
+           'dialog_save_file', 'dialog_select_file', 'guiutil',
+           'window_main']
